from edc_test_settings.func_main import func_main2

if __name__ == "__main__":
    func_main2(
        "tests.test_settings",
        "tests",
        "meta_ae.tests",
        "meta_consent.tests",
        "meta_dashboard.tests",
        "meta_edc.tests",
        "meta_labs.tests",
        "meta_lists.tests",
        "meta_prn.tests",
        "meta_rando.tests",
        "meta_screening.tests",
        "meta_subject.tests",
        "meta_visit_schedule.tests",
    )



from django import forms
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_model_fields.widgets import SliderWidget

from ...form_validators import DmFollowupFormValidator
from ...models import DmFollowup


class DmFollowupForm(CrfModelFormMixin, ActionItemCrfFormMixin, forms.ModelForm):
    form_validator_cls = DmFollowupFormValidator

    visual_score_slider = forms.CharField(
        label="Visual Score", widget=SliderWidget(attrs={"min": 0, "max": 100})
    )

    class Meta:
        model = DmFollowup
        fields = "__all__"
        help_text = {"action_identifier": "(read-only)"}
        widgets = {
            "action_identifier": forms.TextInput(
                attrs={"required": False, "readonly": "readonly"}
            ),
        }



# Generated by Django 4.0.5 on 2022-06-30 11:22

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0035_auto_20220630_1140"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="endofstudy",
            name="meta_prn_en_id_a50384_idx",
        ),
        migrations.RenameField(
            model_name="endofstudy",
            old_name="offschedule_datetime",
            new_name="offstudy_datetime",
        ),
        migrations.RenameField(
            model_name="endofstudy",
            old_name="offschedule_reason",
            new_name="offstudy_reason",
        ),
        migrations.RenameField(
            model_name="endofstudy",
            old_name="other_offschedule_reason",
            new_name="other_offstudy_reason",
        ),
        migrations.RenameField(
            model_name="historicalendofstudy",
            old_name="offschedule_datetime",
            new_name="offstudy_datetime",
        ),
        migrations.RenameField(
            model_name="historicalendofstudy",
            old_name="offschedule_reason",
            new_name="offstudy_reason",
        ),
        migrations.RenameField(
            model_name="historicalendofstudy",
            old_name="other_offschedule_reason",
            new_name="other_offstudy_reason",
        ),
    ]



from django import forms
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..form_validators import GlucoseFormValidator
from ..models import Glucose


class GlucoseForm(CrfModelFormMixin, ActionItemCrfFormMixin, forms.ModelForm):
    form_validator_cls = GlucoseFormValidator

    class Meta(ActionItemCrfFormMixin.Meta):
        model = Glucose
        fields = "__all__"



from django.conf import settings
from django.contrib.sites.models import Site
from django.test import TestCase
from model_bakery.baker import make_recipe

from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin
from meta_subject.forms import FollowupExaminationForm


class TestFollowup(MetaTestCaseMixin, TestCase):
    def setUp(self):
        super().setUp()

        self.subject_visit = self.get_subject_visit()

        self.data = {
            "site": Site.objects.get(id=settings.SITE_ID),
            "report_datetime": None,
            "subject_visit": None,
            "symptoms_detail": None,
            "attended_clinic": None,
            "admitted_hospital": None,
            "attended_clinic_detail": None,
            "prescribed_medication": None,
            "prescribed_medication_detail": None,
            "attended_clinic_sae": None,
            "any_other_problems": None,
            "any_other_problems_detail": None,
            "any_other_problems_sae": None,
            "any_other_problems_sae_grade": None,
            "art_change": None,
            "art_change_reason": None,
            "art_new_regimen_other": None,
            "abdominal_tenderness": None,
            "enlarged_liver": None,
            "jaundice": None,
            "comment": None,
            "lactic_acidosis": None,
            "hepatomegaly": None,
            "referral": None,
            "referral_reason": None,
        }
        self.data.update(
            subject_visit=self.subject_visit.pk,
            report_datetime=self.subject_visit.report_datetime,
        )

    def test_ok(self):
        subject_visit = self.get_next_subject_visit(self.subject_visit)
        obj = make_recipe("meta_subject.followupexamination", subject_visit=subject_visit)
        form = FollowupExaminationForm(instance=obj)
        form.is_valid()



# Generated by Django 4.0.5 on 2022-06-29 15:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0115_historicalegfrnotification_egfrnotification"),
    ]

    operations = [
        migrations.AddField(
            model_name="egfrnotification",
            name="report_status",
            field=models.CharField(
                choices=[
                    ("New", "New"),
                    ("open", "Open. Some information is still pending."),
                    ("closed", "Closed. This report is complete"),
                ],
                default="New",
                max_length=15,
            ),
        ),
        migrations.AddField(
            model_name="historicalegfrnotification",
            name="report_status",
            field=models.CharField(
                choices=[
                    ("New", "New"),
                    ("open", "Open. Some information is still pending."),
                    ("closed", "Closed. This report is complete"),
                ],
                default="New",
                max_length=15,
            ),
        ),
    ]



from django.db import models
from edc_constants.choices import NORMAL_ABNORMAL_NOEXAM
from edc_model.models import BaseUuidModel

from ..choices import (
    FUNDOSCOPY_CHOICES,
    PRESENT_ABSENT_NOEXAM,
    PRESENT_ABSENT_NOEXAM_NDS,
    YES_NO_NO_EXAM,
)
from ..model_mixins import CrfModelMixin


class ComplicationsGlycemia(CrfModelMixin, BaseUuidModel):
    """Not used"""

    # eye examination
    cataracts = models.CharField(
        verbose_name="Presence of cataracts", max_length=15, choices=YES_NO_NO_EXAM
    )

    fundoscopy = models.CharField(
        verbose_name="Fundoscopy", max_length=35, choices=FUNDOSCOPY_CHOICES
    )

    # foot examination
    foot_skin_condition = models.CharField(
        verbose_name="Is the skin of the foot intact and in good condition?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    foot_fungal_infection = models.CharField(
        verbose_name="Is there any fungal infection on the foot?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    foot_sores = models.CharField(
        verbose_name="Are there any foot sores?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    foot_callouses = models.CharField(
        verbose_name="Are there any callouses on the foot?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    # Peripheral pulses and reflexes

    dp_pulse = models.CharField(
        verbose_name="Dorsalis pedis pulse",
        max_length=15,
        choices=PRESENT_ABSENT_NOEXAM,
    )

    pt_pulse = models.CharField(
        verbose_name="Posterior tibial pulse",
        max_length=15,
        choices=PRESENT_ABSENT_NOEXAM,
    )

    at_reflex = models.CharField(
        verbose_name="Achilles tendon reflex",
        max_length=15,
        choices=PRESENT_ABSENT_NOEXAM,
    )

    # Neuropathy Disability Score (NDS)
    nds_vpt_left = models.CharField(
        verbose_name="Vibration perception threshold (left)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text=(
            "128-Hz tuning fork; apex of big toe. "
            "Normal: can distinguish vibrating/Not vibrating"
        ),
    )

    nds_vpt_right = models.CharField(
        verbose_name="Vibration perception threshold (right)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text=(
            "128-Hz tuning fork; apex of big toe. "
            "Normal: can distinguish vibrating/Not vibrating"
        ),
    )

    nds_tp_left = models.CharField(
        verbose_name="Temperature perception on dorsum of foot (left)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text="Use tuning fork with beaker of ice/warm water",
    )

    nds_tp_right = models.CharField(
        verbose_name="Temperature perception on dorsum of foot (right)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text="Use tuning fork with beaker of ice/warm water",
    )

    nds_pp_left = models.CharField(
        verbose_name="Pin-Prick (left)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text="Use tuning fork with beaker of ice/warm water",
    )

    nds_pp_right = models.CharField(
        verbose_name="Pin-Prick (right)",
        max_length=15,
        choices=NORMAL_ABNORMAL_NOEXAM,
        help_text="Use tuning fork with beaker of ice/warm water",
    )

    nds_achilles_reflex_left = models.CharField(
        verbose_name="Achilles reflex (left)",
        max_length=30,
        choices=PRESENT_ABSENT_NOEXAM_NDS,
    )

    nds_achilles_reflex_right = models.CharField(
        verbose_name="Achilles reflex (right)",
        max_length=30,
        choices=PRESENT_ABSENT_NOEXAM_NDS,
    )

    # 10-g monofilament test
    first_metatarsal_left = models.CharField(
        verbose_name="First metatarsal (left)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    first_metatarsal_right = models.CharField(
        verbose_name="First metatarsal (right)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    third_metatarsal_left = models.CharField(
        verbose_name="Third metatarsal (left)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    third_metatarsal_right = models.CharField(
        verbose_name="Third metatarsal (right)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    fifth_metatarsal_left = models.CharField(
        verbose_name="Fifth metatarsal (left)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    fifth_metatarsal_right = models.CharField(
        verbose_name="Fifth metatarsal (right)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    plantar_surface_left = models.CharField(
        verbose_name="Plantar surface of distal hallux (left)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    plantar_surface_right = models.CharField(
        verbose_name="Plantar surface of distal hallux (right)",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    # Diabetic Neuropathy Symptom Score

    dns_walking = models.CharField(
        verbose_name="Are you experiencing unsteadiness in walking?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    dns_burning = models.CharField(
        verbose_name="Do you have burning, aching pain or tenderness in your legs or feet?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    dns_tingling = models.CharField(
        verbose_name="Do you have prickling or tingling sensation in your legs or feet?",
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    dns_numbness = models.CharField(
        verbose_name=(
            "Are you experiencing any numbness or loss of feeling in your legs or feet?"
        ),
        max_length=15,
        choices=YES_NO_NO_EXAM,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Complications (Raised Glycemia)"
        verbose_name_plural = "Complications (Raised Glycemia)"



from copy import copy

from django.conf import settings
from edc_adverse_event.navbars import ae_navbar_item, tmg_navbar_item
from edc_data_manager.navbar_item import dm_navbar_item
from edc_lab_dashboard.navbars import navbar as lab_navbar
from edc_navbar import Navbar, site_navbars
from edc_review_dashboard.navbars import navbar as review_navbar

from meta_dashboard.navbars import navbar as meta_dashboard_navbar

navbar = Navbar(name=settings.APP_NAME)

navbar_item = copy([item for item in lab_navbar.navbar_items if item.name == "specimens"][0])
navbar_item.active = False
navbar_item.label = "Specimens"
navbar.register(navbar_item)

navbar.register(
    [item for item in meta_dashboard_navbar.navbar_items if item.name == "screened_subject"][0]
)

navbar.register(
    [item for item in meta_dashboard_navbar.navbar_items if item.name == "consented_subject"][
        0
    ]
)

for navbar_item in review_navbar.navbar_items:
    navbar.register(navbar_item)

navbar.register(tmg_navbar_item)
navbar.register(ae_navbar_item)
navbar.register(dm_navbar_item)

site_navbars.register(navbar)



# Generated by Django 4.2.11 on 2024-06-06 19:15

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="UnattendedThreeInRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("appt_datetime", models.DateTimeField()),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("third", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Three in a row",
                "verbose_name_plural": "Unattended: Three in a row",
                "db_table": "unattended_three_in_row_view",
                "managed": False,
            },
        ),
        migrations.CreateModel(
            name="UnattendedThreeInRow2",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("third", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("missed_count", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Three in a row (with missed)",
                "verbose_name_plural": "Unattended: Three in a row (with missed)",
                "db_table": "unattended_three_in_row2_view",
                "managed": False,
            },
        ),
        migrations.CreateModel(
            name="UnattendedTwoInRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                ("appt_datetime", models.DateTimeField()),
                ("first", models.CharField(max_length=25)),
                ("second", models.CharField(max_length=25)),
                ("interval_days", models.IntegerField()),
                ("from_now_days", models.IntegerField()),
                ("created", models.DateTimeField()),
            ],
            options={
                "verbose_name": "Unattended: Two in a row",
                "verbose_name_plural": "Unattended: Two in a row",
                "db_table": "unattended_two_in_row_view",
                "managed": False,
            },
        ),
    ]



from edc_qareports.sql_generator import SqlViewGenerator


def get_view_definition() -> dict:
    subquery = """select screening_identifier, site_id, report_datetime as `screening_datetime`, fbg_datetime,
        converted_fbg_value as `fbg_value`,  converted_ogtt_value as `ogtt_value`, fbg2_value, ogtt2_value,
        repeat_glucose_performed as `repeated`, p3_ltfu, fbg2_datetime, ogtt2_datetime, consented,
        screening_identifier as `subject_identifier`, id as `original_id`
        from meta_screening_subjectscreening
        where converted_fbg_value is not null and converted_ogtt_value is null and unsuitable_agreed != "Yes"
        """  # noqa
    sql_view = SqlViewGenerator(
        report_model="meta_reports.missing_screening_ogtt_view",
        ordering=["subject_identifier", "site_id"],
    )
    return {
        "django.db.backends.mysql": sql_view.as_mysql(subquery),
        "django.db.backends.postgresql": sql_view.as_postgres(subquery),
        "django.db.backends.sqlite3": sql_view.as_sqlite(subquery),
    }



from django.db import models
from edc_adverse_event.model_mixins import AeInitialModelMixin
from edc_model.models import BaseUuidModel

from meta_ae.pdf_reports import AePdfReport


class AeMetaModelMixin(models.Model):
    class Meta:
        abstract = True


class AeInitial(AeInitialModelMixin, AeMetaModelMixin, BaseUuidModel):
    pdf_report_cls = AePdfReport

    class Meta(AeInitialModelMixin.Meta):
        pass



# Generated by Django 3.2.6 on 2021-08-17 20:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0080_auto_20210812_0400"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmnsi",
            name="amputation",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an amputation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ankle_reflexes_left_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ankle_reflexes_right_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="burning_pain_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any burning pain in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="covers_touch_skin_painful",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Does it hurt when the bed covers touch your skin?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="diabetic_neuropathy",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="differentiate_hot_cold_water",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="examined_left_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the LEFT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="examined_right_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the RIGHT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="feel_weak",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you feel weak all over most of the time?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="feet_sensitive_touch",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your feet too sensitive to touch?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="legs_hurt_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do your legs hurt when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="mnsi_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Is the MNSI assessment being performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="monofilament_left_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="monofilament_right_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="muscle_cramps_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you get muscle cramps in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="normal_appearance_left_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does LEFT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="normal_appearance_right_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does RIGHT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="numb_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your legs and/or feet numb?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="open_sore_foot_history",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an open sore on your foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="prickling_feelings_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any prickling feelings in your legs or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="sense_feet_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are you able to sense your feet when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="skin_cracks_open_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the skin on your feet so dry that it cracks open?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="symptoms_worse_night",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your symptoms worse at night?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ulceration_left_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="ulceration_right_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="vibration_perception_left_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="vibration_perception_right_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="amputation",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an amputation?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ankle_reflexes_left_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ankle_reflexes_right_foot",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("present_with_reinforcement", "Present/Reinforcement"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ankle reflexes, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="burning_pain_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any burning pain in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="covers_touch_skin_painful",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Does it hurt when the bed covers touch your skin?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="diabetic_neuropathy",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="differentiate_hot_cold_water",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="examined_left_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the LEFT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="examined_right_foot",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If the assessment was not performed, respond with `not applicable`.",
                max_length=15,
                verbose_name="Was the RIGHT foot examined?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="feel_weak",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you feel weak all over most of the time?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="feet_sensitive_touch",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your feet too sensitive to touch?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="legs_hurt_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do your legs hurt when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="mnsi_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Is the MNSI assessment being performed?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="monofilament_left_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="monofilament_right_foot",
            field=models.CharField(
                choices=[
                    ("NORMAL", "Normal"),
                    ("reduced", "Reduced"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Monofilament, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="muscle_cramps_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you get muscle cramps in your legs and/or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="normal_appearance_left_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does LEFT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="normal_appearance_right_foot",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=15,
                verbose_name="Does RIGHT foot appear normal?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="numb_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your legs and/or feet numb?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="open_sore_foot_history",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Have you ever had an open sore on your foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="prickling_feelings_legs_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Do you ever have any prickling feelings in your legs or feet?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="sense_feet_when_walk",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are you able to sense your feet when you walk?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="skin_cracks_open_feet",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the skin on your feet so dry that it cracks open?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="symptoms_worse_night",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Are your symptoms worse at night?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ulceration_left_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="ulceration_right_foot",
            field=models.CharField(
                choices=[
                    ("absent", "Absent"),
                    ("present", "Present"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Ulceration, RIGHT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="vibration_perception_left_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, LEFT foot?",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="vibration_perception_right_toe",
            field=models.CharField(
                choices=[
                    ("present", "Present"),
                    ("decreased", "Decreased"),
                    ("absent", "Absent"),
                    ("not_examined", "Not examined"),
                ],
                default="not_examined",
                help_text="If the assessment was not performed or this foot was not examined, respond with `not examined`.",
                max_length=35,
                verbose_name="Vibration perception at great toe, RIGHT foot?",
            ),
        ),
    ]



import pandas as pd

from .constants import endpoint_columns


def get_test_string(s):
    if pd.notna(s["fbg_value"]) and pd.notna(s["ogtt_value"]):
        return "fbg_ogtt"
    if pd.notna(s["fbg_value"]) and pd.isna(s["ogtt_value"]):
        return "fbg_only"
    if pd.isna(s["fbg_value"]) and pd.notna(s["ogtt_value"]):
        return "ogtt_only"
    if pd.isna(s["fbg_value"]) and pd.isna(s["ogtt_value"]):
        return "not_tested"
    return "???"


def get_empty_endpoint_df() -> pd.DataFrame:
    endpoint_df = pd.DataFrame(columns=endpoint_columns)
    endpoint_df[
        [
            "visit_code",
            "interval_in_days",
            "fbg_value",
            "ogtt_value",
            "endpoint",
            "endpoint_type",
        ]
    ] = endpoint_df[
        [
            "visit_code",
            "interval_in_days",
            "fbg_value",
            "ogtt_value",
            "endpoint",
            "endpoint_type",
        ]
    ].apply(
        pd.to_numeric
    )
    endpoint_df[
        ["baseline_datetime", "visit_datetime", "fbg_datetime", "offstudy_datetime"]
    ] = endpoint_df[
        ["baseline_datetime", "visit_datetime", "fbg_datetime", "offstudy_datetime"]
    ].apply(
        pd.to_datetime
    )
    endpoint_df["visit_code"] = endpoint_df["visit_code"].astype(float)
    return endpoint_df


def get_unique_visit_codes(df: pd.DataFrame) -> pd.DataFrame:
    stats_df = df[df["visit_code"] % 1 == 0]["visit_code"].value_counts().to_frame()
    stats_df = stats_df.reset_index()
    stats_df["visit_code"] = stats_df["visit_code"].astype(float)
    stats_df = stats_df.sort_values(["visit_code"])
    stats_df = stats_df.reset_index(drop=True)
    return stats_df


def get_unique_subject_identifiers(df: pd.DataFrame) -> pd.DataFrame:
    values_df = pd.DataFrame(df["subject_identifier"].unique(), columns=["subject_identifier"])
    values_df = values_df.sort_values(["subject_identifier"])
    values_df = values_df.reset_index()
    return values_df



from typing import Tuple

from django.contrib import admin
from django.core.exceptions import ObjectDoesNotExist
from django.template.loader import render_to_string
from django.urls import NoReverseMatch, reverse
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin
from edc_registration.models import RegisteredSubject
from edc_sites.admin import SiteModelAdminMixin

from ..admin_site import meta_subject_admin
from ..forms import BirthOutcomesForm
from ..models import BirthOutcomes


@admin.register(BirthOutcomes, site=meta_subject_admin)
class BirthOutcomesAdmin(
    SiteModelAdminMixin,
    ModelAdminSubjectDashboardMixin,
    SimpleHistoryAdmin,
):
    form = BirthOutcomesForm

    fieldsets = (
        (None, {"fields": ("delivery", "report_datetime")}),
        (
            "Birth Outcome",
            {
                "fields": (
                    "birth_order",
                    "birth_outcome",
                    "birth_weight",
                )
            },
        ),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    list_display = (
        "delivery_report",
        "dashboard",
        "birth_order",
        "birth_outcome",
    )

    radio_fields = {
        "birth_outcome": admin.VERTICAL,
    }

    def get_list_filter(self, request) -> Tuple[str, ...]:
        fields = super().get_list_filter(request)
        custom_fields = (
            "birth_order",
            "birth_outcome",
        )
        return custom_fields + fields

    def get_search_fields(self, request) -> Tuple[str, ...]:
        fields = super().get_search_fields(request)
        custom_fields = (
            "delivery__subject_visit__subject_identifier",
            "delivery__action_identifier",
        )
        return tuple(set(fields + custom_fields))

    @admin.display
    def delivery_report(self, obj=None, label=None):
        url = reverse("meta_subject_admin:meta_subject_delivery_changelist")
        url = f"{url}?q={obj.subject_identifier}"
        context = dict(title="Delivery", url=url, label="Delivery")
        return render_to_string("dashboard_button.html", context=context)

    def get_subject_dashboard_url_kwargs(self, obj):
        return dict(subject_identifier=obj.subject_identifier)

    def view_on_site(self, obj):
        try:
            RegisteredSubject.objects.get(subject_identifier=obj.subject_identifier)
        except ObjectDoesNotExist:
            url = reverse(self.get_subject_listboard_url_name())
        else:
            try:
                url = reverse(
                    self.get_subject_dashboard_url_name(),
                    kwargs=self.get_subject_dashboard_url_kwargs(obj),
                )
            except NoReverseMatch as e:
                if callable(super().view_on_site):
                    url = super().view_on_site(obj)
                else:
                    raise NoReverseMatch(
                        f"{e}. See subject_dashboard_url_name for {repr(self)}."
                    )
        return url



from typing import Any

from edc_constants.constants import DM, NO, NORMAL, NOT_APPLICABLE, PENDING, TBD, YES
from edc_screening.fc import FC

from ...constants import (
    EGFR_LT_45,
    FBG_OGTT_INCOMPLETE,
    HI_FBG,
    HI_OGTT,
    NORMAL_FBG_OGTT,
    PRE_DM,
    SEVERE_HTN,
)
from .base_eligibility_part_three import BaseEligibilityPartThree


class EligibilityPartThreePhaseThree(BaseEligibilityPartThree):
    def __init__(self, **kwargs):
        self.inclusion_a = TBD
        self.inclusion_b = TBD
        self.severe_htn = None
        super().__init__(**kwargs)

    def assess_eligibility(self: Any) -> None:
        """Subject is eligible if either a qualifying FBG (pre-diabetes)
        OR a qualifying OGTT

        However, OGTT overrides FBG. For example, a qualifying FBG
        that suggest pre-diabetes cannot override an OGTT that
        implies diabetes.

        FBG-HI + OGTT-HI -> NO
        FBG-HI + OGTT-PRE -> YES
        FBG-HI + OGTT-NORMAL -> NO

        FBG-PRE + OGTT-HI -> NO
        FBG-PRE + OGTT-PRE -> YES
        FBG-PRE + OGTT-NORMAL -> YES **(note FBG overrides
                                        OGTT in this case)

        FBG-NORMAL + OGTT-HI -> NO
        FBG-NORMAL + OGTT-PRE -> YES
        FBG-NORMAL + OGTT-NORMAL -> NO
        """
        # TODO: check if calculates correctly if glucose is HIGH 9999.99
        super().assess_eligibility()
        if (
            self.repeat_glucose_performed == PENDING
            or not self.fbg_category
            or not self.ogtt_category
        ):
            self.eligible = TBD
            self.reasons_ineligible.update(fbg_ogtt_incomplete=FBG_OGTT_INCOMPLETE)
        else:
            if self.ogtt_category == PRE_DM:
                self.eligible = YES
            elif self.ogtt_category == DM:
                self.eligible = NO
                self.reasons_ineligible.update(hi_ogtt=HI_OGTT)
            elif self.fbg_category == PRE_DM and self.ogtt_category == NORMAL:
                self.eligible = YES
            elif self.fbg_category == NORMAL and self.ogtt_category == NORMAL:
                self.eligible = NO
                self.reasons_ineligible.update(normal_fbg_ogtt=NORMAL_FBG_OGTT)
            elif self.fbg_category == DM and self.ogtt_category == NORMAL:
                self.eligible = NO
                self.reasons_ineligible.update(hi_fbg=HI_FBG)
        if self.calculated_egfr_value and self.calculated_egfr_value < 45.0:
            self.reasons_ineligible.update(egfr_low=EGFR_LT_45)
            self.eligible = NO

    def set_fld_attrs_on_model(self: Any) -> None:
        """Set extra attr on the model"""
        super().set_fld_attrs_on_model()
        self.model_obj.inclusion_a = self.inclusion_a
        self.model_obj.inclusion_b = self.inclusion_b
        self.model_obj.inclusion_c = NOT_APPLICABLE
        self.model_obj.inclusion_d = NOT_APPLICABLE

    def get_required_fields(self: Any) -> dict[str, FC]:
        """Get default fields as well as severe_htn"""
        fields = super().get_required_fields()
        fields.update({"severe_htn": FC(NO, SEVERE_HTN)})
        return fields

    @property
    def fbg_category(self):
        # FBG (6.1 to 6.9 mmol/L)
        value = (
            self.converted_fbg2_value
            if self.repeat_glucose_opinion == YES
            else self.converted_fbg_value
        )
        if not value:
            fbg_category = None
        elif 6.1 <= value < 7.0:
            fbg_category = PRE_DM
        elif value >= 7.0:
            fbg_category = DM
        elif value < 6.1:
            fbg_category = NORMAL
        else:
            raise ValueError("Invalid FBG value")
        return fbg_category

    @property
    def ogtt_category(self):
        # OGTT (7.8 to 11.10 mmol/L)
        value = (
            self.converted_ogtt2_value
            if self.repeat_glucose_opinion == YES
            else self.converted_ogtt_value
        )
        if not value:
            ogtt_category = None
        elif 7.8 <= value < 11.1:
            ogtt_category = PRE_DM
        elif value >= 11.1:
            ogtt_category = DM
        elif value < 7.8:
            ogtt_category = NORMAL
        else:
            raise ValueError("Invalid OGTT value")
        return ogtt_category



# Generated by Django 4.0.5 on 2022-07-03 19:15

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_crypto_fields.fields.encrypted_text_field
import django_revision.revision_field
import edc_action_item.models.action_model_mixin
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("edc_action_item", "0028_auto_20210203_0706"),
        ("meta_lists", "0013_transferreasons_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        (
            "meta_prn",
            "0040_remove_historicaloffstudymedication_expected_restart_date_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="endofstudy",
            name="transfer_date",
            field=models.DateField(
                blank=True,
                help_text="A Transfer form must be on file.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date of transfer, if applicable",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="transfer_date",
            field=models.DateField(
                blank=True,
                help_text="A Transfer form must be on file.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date of transfer, if applicable",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="offstudy_reason",
            field=models.ForeignKey(
                limit_choices_to={
                    "name__in": [
                        "clinical_withdrawal",
                        "completed_followup",
                        "dead",
                        "delivery",
                        "diabetes",
                        "late_exclusion",
                        "LTFU",
                        "OTHER",
                        "pregnancy",
                        "toxicity",
                        "transferred",
                        "withdrawal",
                    ]
                },
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="meta_lists.offstudyreasons",
                verbose_name="Reason patient was terminated from the study",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="toxicity_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("lactic_acidosis", "Development of lactic acidosis or hyperlactatemia"),
                    ("hepatomegaly", "Development of hepatomegaly with steatosis"),
                    ("OTHER", "Other (specify below)"),
                ],
                max_length=25,
                null=True,
                verbose_name=" Patient experienced an unacceptable toxicity, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="offstudy_reason",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={
                    "name__in": [
                        "clinical_withdrawal",
                        "completed_followup",
                        "dead",
                        "delivery",
                        "diabetes",
                        "late_exclusion",
                        "LTFU",
                        "OTHER",
                        "pregnancy",
                        "toxicity",
                        "transferred",
                        "withdrawal",
                    ]
                },
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.offstudyreasons",
                verbose_name="Reason patient was terminated from the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="toxicity_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("lactic_acidosis", "Development of lactic acidosis or hyperlactatemia"),
                    ("hepatomegaly", "Development of hepatomegaly with steatosis"),
                    ("OTHER", "Other (specify below)"),
                ],
                max_length=25,
                null=True,
                verbose_name=" Patient experienced an unacceptable toxicity, please specify ...",
            ),
        ),
        migrations.CreateModel(
            name="SubjectTransfer",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                ("tracking_identifier", models.CharField(max_length=32, unique=True)),
                ("action_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow, verbose_name="Report Date and Time"
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        default=edc_utils.date.get_utcnow, verbose_name="Transfer date"
                    ),
                ),
                (
                    "initiated_by",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("clinician", "Attending Clinician / Healthcare worker"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="Who initiated the transfer request",
                    ),
                ),
                (
                    "initiated_by_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "transfer_reason_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "may_return",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                        max_length=15,
                        verbose_name="Is the participant likely to transfer back before the end of their stay in the trial?",
                    ),
                ),
                (
                    "may_contact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the participant willing to be contacted at the end of the study?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        verbose_name="Additional Comments",
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "transfer_reason",
                    models.ManyToManyField(
                        to="meta_lists.transferreasons", verbose_name="Reason for transfer"
                    ),
                ),
            ],
            options={
                "verbose_name": "Subject Transfer",
                "verbose_name_plural": "Subject Transfers",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalSubjectTransfer",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                ("tracking_identifier", models.CharField(db_index=True, max_length=32)),
                ("action_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow, verbose_name="Report Date and Time"
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        default=edc_utils.date.get_utcnow, verbose_name="Transfer date"
                    ),
                ),
                (
                    "initiated_by",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("clinician", "Attending Clinician / Healthcare worker"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="Who initiated the transfer request",
                    ),
                ),
                (
                    "initiated_by_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "transfer_reason_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "may_return",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                        max_length=15,
                        verbose_name="Is the participant likely to transfer back before the end of their stay in the trial?",
                    ),
                ),
                (
                    "may_contact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the participant willing to be contacted at the end of the study?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        verbose_name="Additional Comments",
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Subject Transfer",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-27 23:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0007_auto_20200516_2356"),
        ("meta_subject", "0040_auto_20200527_2155"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalfollowup",
            name="art_new_regimen",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.ArvRegimens",
                verbose_name="Please indicate new regimen",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="admitted_hospital",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="If YES, were they admitted to hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="any_other_problems",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Since your last visit has the participant experienced any other medical or health problems NOT listed above",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="any_other_problems_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If YES, please provide details of the event",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="any_other_problems_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Does this event constitute an Adverse Event?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="art_change",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Since the participant's last visit has there been any change in their HIV medication?",
            ),
        ),
        migrations.RemoveField(
            model_name="followup",
            name="art_new_regimen",
        ),
        migrations.AddField(
            model_name="followup",
            name="art_new_regimen",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="art_new_regimen",
                to="meta_lists.ArvRegimens",
                verbose_name="Please indicate new regimen",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last visit did they attend any other clinic or hospital for care for any reason",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend other clinic or hospital, please provide details of this event",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="attended_clinic_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, submit a <u>Serious Adverse Event</u> Form",
                max_length=25,
                verbose_name="Does the event constitute a <u>Serious Adverse Event</u>",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="hepatomegaly",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome",
                max_length=25,
                verbose_name="Do you think the participant has hepatomegaly with steatosis?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="lactic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.",
                max_length=25,
                verbose_name="Do you think the participant has lactic acidosis?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="prescribed_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the participant prescribed any other medication at this clinic or hospital visit?",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="referral",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Is the participant being referred",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="symptoms",
            field=models.ManyToManyField(
                help_text="either at this hospital or at a different clinic",
                related_name="symptoms",
                to="meta_lists.Symptoms",
                verbose_name="Since the participant's last appointment have they experienced any of the following symptoms",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="symptoms_sought_care",
            field=models.ManyToManyField(
                related_name="symptoms_sought_care",
                to="meta_lists.Symptoms",
                verbose_name="Did they seek care from any health worker for these symptoms",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="admitted_hospital",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="If YES, were they admitted to hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="any_other_problems",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Since your last visit has the participant experienced any other medical or health problems NOT listed above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="any_other_problems_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If YES, please provide details of the event",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="any_other_problems_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Does this event constitute an Adverse Event?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="art_change",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Since the participant's last visit has there been any change in their HIV medication?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last visit did they attend any other clinic or hospital for care for any reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend other clinic or hospital, please provide details of this event",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="attended_clinic_sae",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, submit a <u>Serious Adverse Event</u> Form",
                max_length=25,
                verbose_name="Does the event constitute a <u>Serious Adverse Event</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="hepatomegaly",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This condition often does not have any clinical signs and symptoms, it may present with an enlarge liver on examination, and symptoms of fatigue and right upper abdominal pain. The risk of developing this condition is higher in patients who are obese and who have type 2 diabetes or metabolic syndrome",
                max_length=25,
                verbose_name="Do you think the participant has hepatomegaly with steatosis?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="lactic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Classical signs of lactic acidosis include: abdominal or stomach discomfort, decreased appetite, diarrhoea, fast or shallow breathing, a general feeling of discomfort, muscle pain or cramping; and unusual sleepiness, fatigue, or weakness.",
                max_length=25,
                verbose_name="Do you think the participant has lactic acidosis?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="prescribed_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the participant prescribed any other medication at this clinic or hospital visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="referral",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Is the participant being referred",
            ),
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-26 12:10

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "meta_prn",
            "0027_rename_historicalprotocoldeviationviolation_historicalprotocolincident_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpregnancynotification",
            name="bhcg_date",
            field=models.DateField(
                blank=True,
                help_text="Will be validated against a UPT result in the EDC.",
                null=True,
                verbose_name="βHCG result date",
            ),
        ),
        migrations.AddField(
            model_name="pregnancynotification",
            name="bhcg_date",
            field=models.DateField(
                blank=True,
                help_text="Will be validated against a UPT result in the EDC.",
                null=True,
                verbose_name="βHCG result date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancynotification",
            name="bhcg_confirmed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, the UPT result must already be entered in the EDC.",
                max_length=5,
                verbose_name="Has the pregnancy been confirmed by urine βHCG?",
            ),
        ),
        migrations.AlterField(
            model_name="pregnancynotification",
            name="bhcg_confirmed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If YES, the UPT result must already be entered in the EDC.",
                max_length=5,
                verbose_name="Has the pregnancy been confirmed by urine βHCG?",
            ),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-18 02:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0002_patienthistorymissingbaselinecd4_and_more"),
    ]

    operations = []
